@@ -16,7 +16,7 @@ base_id <- function(nDomains = 10, nUnits = 10) {
             if(length(nUnits) > 1) length(nUnits) == nDomains else TRUE)
   
   out <- data.frame(idD = rep(1:nDomains, times = nUnits)) %>% 
-    s_group_by("idD") %>% mutate(idU = 1:n()) %>% s_arrange("idD", "idU")
+    group_by_("idD") %>% mutate(idU = 1:n()) %>% arrange_("idD", "idU")
   
   out <- if(length(nUnits) == 1 && nUnits == 1) out["idD"] else out
   as.data.frame(out)
