@@ -1,6 +1,8 @@
 context("sim_comp")
+
 test_that("sim_comp and comp_var", {
   setup <- sim_base(base_id(nDomains=5, nUnits = 10)) %>% 
+    sim_gen(addAttr) %>%
     sim_gen_x(mean=50, sd=20) %>%
     sim_gen_e(0, 1) %>%
     sim_gen_ec() %>%
@@ -13,7 +15,8 @@ test_that("sim_comp and comp_var", {
     as.data.frame
   
   calc_lm <- function(dat) {
-    dat$linearPredictor <- predict(lm(y ~ x, data = dat))
+    linearModel <- lm(y ~ x, data = dat)
+    dat$linearPredictor <- predict(linearModel)
     dat
   }
   
@@ -24,4 +27,6 @@ test_that("sim_comp and comp_var", {
   expect_equal(unique(dat$n), 5)
   expect_equal(unique(dat$N), 10)
   expect_that(dat1$linearPredictor, is_equivalent_to(predict(lm(y ~ x, data = dat1))))
+  expect_equal(attr(dat, "x"), 1)
+  expect_equal(attr(dat1, "x"), 1)
 })
\ No newline at end of file
